pub fn execute_plan<'a>(
plan: &'a ExecutionPlan,
ports: &'a ExecutePorts<'a>,
) -> Result<(), StepFailure>Expand description
Runs every example in plan, in order, stopping at the first failure. Port
of executePlan.
pub fn execute_plan<'a>(
plan: &'a ExecutionPlan,
ports: &'a ExecutePorts<'a>,
) -> Result<(), StepFailure>Runs every example in plan, in order, stopping at the first failure. Port
of executePlan.