references

Function references 

pub fn references(doc: &Doc) -> Vec<Reference>
Every reference block in a document, in document order. The shell uses this to walk the closure of documents it must read before planning.