pub struct ReferencedDocument {
pub path: String,
pub source_hash: String,
}Expand description
An oath other than this one that contributed steps to the run, with its source hash as run (ADR 0016).
Fields
path: Stringsource_hash: StringTrait Implementations
Sourceimpl Clone for ReferencedDocument
impl Clone for ReferencedDocument
Sourcefn clone(&self) -> ReferencedDocument
fn clone(&self) -> ReferencedDocument
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ReferencedDocument
impl Debug for ReferencedDocument
impl Eq for ReferencedDocument
Sourceimpl PartialEq for ReferencedDocument
impl PartialEq for ReferencedDocument
impl StructuralPartialEq for ReferencedDocument